var http = require('http');
var createError = require("http-errors");
var debug = require('debug')('booking-client:server');
var express = require("express");
var path = require("path");
var cookieParser = require("cookie-parser");
var logger = require("morgan");
const cors = require("cors");
require("dotenv").config();

const connectMongo = require("./connections/mongoose");

var indexRouter = require("./routes/index");
var usersRouter = require("./routes/users");
var reviewRouter=require("./routes/review")
const authRoutes = require("./routes/auth/auth");
const homeRouter=require("./routes/home")
const clinicRouter = require("./routes/clinic");

const hospitalRoutes = require("./routes/hospital");
const doctorRoutes = require("./routes/doctor");
const appointmentRoutes = require("./routes/appointment");
const freelanceRoutes = require("./routes/freelance");
const departmentsRoutes = require("./routes/Department");
const treatmentsRoutes = require("./routes/Treatment");
const consultationRequestRoutes = require("./routes/ConsultationReques");
const airambulanceRoutes=require("./routes/airambulance");
const medicalexpressRoutes=require("./routes/medicalexpress")
const healthcareRoutes=require("./routes/healthcare");
const enquiryRoutes = require('./routes/enquiry');
const guestRoutes = require('./routes/guest')
const contactRoutes=require("./routes/contact")
const notificationRoutes=require("./routes/notification")
const countryRoutes = require('./routes/country');
const stateRoutes = require('./routes/state');
const cityRoutes = require('./routes/city');
const insuranceRoutes=require("./routes/insurance")
const bannerRoutes=require('./routes/banner');
const { authenticateToken } = require('./service/JWT');

var app = express();

// view engine setup
app.set("views", path.join(__dirname, "views"));
app.set("view engine", "jade");

app.use(logger("dev"));
app.use(express.json());
app.use(cors());
app.use(express.urlencoded({ extended: false }));
app.use(cookieParser());
app.use(express.static(path.join(__dirname, "public")));



// Connect to database
connectMongo();

app.use("/api/v1/", indexRouter);
app.use("/api/v1/users",authenticateToken, usersRouter);
app.use("/api/v1/reviews",reviewRouter)
app.use("/api/v1/auth", authRoutes);

app.use("/api/v1/home",homeRouter);
app.use("/api/v1/clinics", clinicRouter);
app.use("/api/v1/insurances",insuranceRoutes)
app.use("/api/v1/appointments", appointmentRoutes);
app.use("/api/v1/hospitals", hospitalRoutes);
app.use("/api/v1/doctors", doctorRoutes);
app.use("/api/v1/banners",bannerRoutes)
app.use("/api/v1/freelance", freelanceRoutes);
app.use("/api/v1/departments", departmentsRoutes);
app.use("/api/v1/treatments", treatmentsRoutes);
app.use("/api/v1/airambulances",airambulanceRoutes)
app.use("/api/v1/consultation", consultationRequestRoutes);
app.use("/api/v1/medical",medicalexpressRoutes);
app.use("/api/v1/healthcare",healthcareRoutes);
app.use("/api/v1/enquiry",enquiryRoutes);
app.use("/api/v1/guest",guestRoutes)
app.use("/api/v1/contactinfo",contactRoutes)
app.use("/api/v1/notification", authenticateToken, notificationRoutes);
app.use('/api/v1/countries', countryRoutes);
app.use('/api/v1/states', stateRoutes);
app.use('/api/v1/cities', cityRoutes);



app.get("*",  (req, res)=> {
  res.sendFile('public/index.html', { root: __dirname });
})
// catch 404 and forward to error handler
app.use(function (req, res, next) {
  next(createError(404));
});

// error handler
app.use(function (err, req, res, next) {
  // set locals, only providing error in development
  res.locals.message = err.message;
  res.locals.error = req.app.get("env") === "development" ? err : {};

  // render the error page
  res.status(err.status || 500);
  res.render("error");
});


/**
 * Get port from environment and store in Express.
 */

var port = normalizePort(process.env.PORT || '3030');
app.set('port', port);

/**
 * Create HTTP server.
 */

var server = http.createServer(app);

/**
 * Listen on provided port, on all network interfaces.
 */

server.listen(port);
server.on('error', onError);
server.on('listening', onListening);

/**
 * Normalize a port into a number, string, or false.
 */

function normalizePort(val) {
  var port = parseInt(val, 10);

  if (isNaN(port)) {
    // named pipe
    return val;
  }

  if (port >= 0) {
    // port number
    return port;
  }

  return false;
}

/**
 * Event listener for HTTP server "error" event.
 */

function onError(error) {
  if (error.syscall !== 'listen') {
    throw error;
  }

  var bind = typeof port === 'string'
    ? 'Pipe ' + port
    : 'Port ' + port;

  // handle specific listen errors with friendly messages
  switch (error.code) {
    case 'EACCES':
      console.error(bind + ' requires elevated privileges');
      process.exit(1);
      break;
    case 'EADDRINUSE':
      console.error(bind + ' is already in use');
      process.exit(1);
      break;
    default:
      throw error;
  }
}

/**
 * Event listener for HTTP server "listening" event.
 */

function onListening() {
  var addr = server.address();
  var bind = typeof addr === 'string'
    ? 'pipe ' + addr
    : 'port ' + addr.port;
    console.log(addr.port);
  debug('Listening on ' + bind);
}

module.exports = app;
