const ConsultationRequest = require('../../model/ConsultationRequest');


exports.createConsultationRequest = async (req, res) => {
  try {
    const { patient, doctor, requestDate,  consultationDate, status } = req.body;

    if (!patient|| !doctor || !requestDate || !consultationDate, !status) {
      return res.status(400).json({ error: 'Please provide all fields' });
    }

    const newRequest = new ConsultationRequest({
      patient,
      doctor,
      requestDate,
      consultationDate,
      status
    });

    await newRequest.save();

    res.status(201).json({ message: 'Consultation request created successfully' });
  } catch (error) {
    res.status(500).json({ error: 'Error creating consultation request' });
  }
};

// View and approve consultation requests
exports.viewAndApproveRequests = async (req, res) => {
  try {
    const pendingRequests = await ConsultationRequest.find({ status: 'Pending' });
    res.json(pendingRequests);
  } catch (error) {
    res.status(500).json({ error: 'Error fetching requests' });
  }
};

// List active requests
exports.listActiveRequests = async (req, res) => {
  try {
    const activeRequests = await ConsultationRequest.find({ status: 'Approved' });
    res.json(activeRequests);
  } catch (error) {
    res.status(500).json({ error: 'Error fetching active requests' });
  }
};

// List past requests
exports.listPastRequests = async (req, res) => {
  try {
    const pastRequests = await ConsultationRequest.find({ status: 'Completed' });
    res.json(pastRequests);
  } catch (error) {
    res.status(500).json({ error: 'Error fetching past requests' });
  }
};

// Approve a request
exports.approveRequest = async (req, res) => {
  try {
    const requestId = req.params.id;
    await ConsultationRequest.findByIdAndUpdate(requestId, { status: 'Approved' });
    res.json({ message: 'Request approved' });
  } catch (error) {
    res.status(500).json({ error: 'Error approving request' });
  }
};





// exports.listConsultationRequests = async (req, res) => {
//     try {
//       const consultationRequests = await ConsultationRequest.find();
//       res.json(consultationRequests);
//     } catch (err) {
//       res.status(500).json({ error: err });
//     }
//   };

//   // Approve or reject a consultation request
// exports.approveConsultationRequest = async (req, res) => {
//     try {
//       const requestId = req.params.requestId;
//       const { action } = req.body; // Action can be 'approve' or 'reject'
  
//       const consultationRequest = await ConsultationRequest.findById(requestId);
  
//       if (!consultationRequest) {
//         return res.status(404).json({ message: 'Consultation request not found' });
//       }
  
//       if (action === 'approve') {
//         consultationRequest.status = 'Approved';
//       } else if (action === 'reject') {
//         consultationRequest.status = 'Rejected';
//       } else {
//         return res.status(400).json({ message: 'Invalid action' });
//       }
  
//       const updatedRequest = await consultationRequest.save();
//       res.json(updatedRequest);
//     } catch (err) {
//       res.status(500).json({ error: err.message });
//     }
//   };
  
//   // List active requests (e.g., pending and approved requests)
//   exports.listActiveRequests = async (req, res) => {
//     try {
//       const activeRequests = await ConsultationRequest.find({ status: { $in: ['Pending', 'Approved'] }});
//       res.json(activeRequests);
//     } catch (err) {
//       res.status(500).json({ error: err.message });
//     }
//   };
  
//   // List past requests (e.g., completed requests)
//   exports.listPastRequests = async (req, res) => {
//     try {
//       const pastRequests = await ConsultationRequest.find({ status: 'Completed' });
//       res.json(pastRequests);
//     } catch (err) {
//       res.status(500).json({ error: err.message });
//     }
//   };
