const User = require("../../model/Users");
const Guest = require('../../model/Guest')
const Enquiry = require("../../model/Enquiry");
const { sendMail } = require("../../service/sendMail");
const EnquiryBooked = require("../../utils/emailTemplates/EnquiryBooking");
const EnquiryRejected = require("../../utils/emailTemplates/EnquiryRejected");
const Notification = require("../../model/Notification");
const sendPushNotification = require("../../model/Notification");

exports.createEnquiry = async (req, res) => {
  console.log(req.body, "request");
  try {
    const { serviceId, userId,guestId, enquiryType, name } = req.body;
    let user, guest;
    if (userId) {
      user = await User.findOne({ _id: userId });
    }

    // Check if guestId is provided
    if (guestId) {
      guest = await Guest.findOne({ _id: guestId });
    }
    // const user = await User.findOne({ _id: userId });
    console.log(req.body);
    const enquiryData = {
      userId,
      enquiryType,
    };
    switch (name) {
      case "hospital":
        enquiryData.hospitalId = serviceId;
        break;
      case "clinic":
        enquiryData.clinicId = serviceId;
        break;
      case "airambulance":
        enquiryData.airambulanceId = serviceId;
        break;
      case "healthcare":
        enquiryData.healthcareId = serviceId;
        break;
      case "medicalexpress":
        enquiryData.medicalexpressId = serviceId;
        break;
      case "doctor":
        enquiryData.doctorId = serviceId;
        break;
      default:
        break;
    }
    const enquiry = new Enquiry(enquiryData);
    await enquiry.save();
    console.log("ss", user?.role);

    const admins = await User.find({ role: "admin" });
    const adminIds = admins.map((admin) => admin._id.toString());
    console.log("aaa", adminIds);

    // const adminIds = admins.map(admin => admin._id);
    // console.log('aaa',adminIds)
    // if (user.role === "admin") {
    const notificationData = {
      title: "New Enquiry",
      body: `A new enquiry has been created for service ${serviceId}`,
    };
    if (user && user.deviceTokens) {
    for (const token of user?.deviceTokens) {
      await sendPushNotification(
        {
          notification: notificationData,
          token,
        },
        user.toJSON()
      );
    }
  }
    const notification = new Notification({
      ...notificationData,
      userId: userId,
      adminIds: adminIds,
    });
    await notification.save();
    // }
    res.status(201).json({ message: "Enquiry created successfully", enquiry });
  } catch (error) {
    console.error(error);
    res.status(500).json({ message: "Internal server error" });
  }
};

exports.getEnquiriesByServiceId = async (req, res) => {
  try {
    const { serviceId } = req.params;
    const enquiries = await Enquiry.find({ serviceId });
    res.status(200).json(enquiries);
  } catch (error) {
    console.error(error);
    res.status(500).json({ message: "Internal server error" });
  }
};

exports.getEnquiries = async (req, res) => {
  try {
    const enquiries = await Enquiry.find()
      .populate(
        "hospitalId clinicId airambulanceId healthcareId medicalexpressId doctorId"
      )
      .populate("userId")
      .sort({ _id: -1 });
    res.status(200).json(enquiries);
  } catch (error) {
    console.log(error);
    res.status(500).json({ message: "Internal server error" });
  }
};

exports.togglestatus = async (req, res) => {
  let { id } = req.params;
  let { userId, uid, status } = req.body;
  const userMakingEnquiry = await User.findById(uid);
  const user = userMakingEnquiry.name;
  console.log(userMakingEnquiry);
  console.log("this is status", req.body);
  // const user = await User.findOne({ _id: userId });
  try {
    let enquiry = await Enquiry.findById(id);
    enquiry.status = status;
    await enquiry.save();
    if (status === "Booked") {
      const emailContent = EnquiryBooked({ user });
      await sendMail({
        ...emailContent,
        from: `<${process.env.AUTH_EMAIL}>`,
        to: `${userMakingEnquiry.email}`,
      });
    } else if (status === "Rejected") {
      const emailContent = EnquiryRejected({ user });
      await sendMail({
        ...emailContent,
        from: `<${process.env.AUTH_EMAIL}>`,
        to: `${userMakingEnquiry.email}`,
      });
    }

    // let notificationData;
    // if (status === "Booked") {
    //   notificationData = {
    //     title: "Appointment Booked!",
    //     body: "Congratulations! Your appointment has been booked.",
    //   };
    // } else if (status === "Rejected") {
    //   notificationData = {
    //     title: "Appointment Canceled",
    //     body: "Unfortunately, your appointment has been canceled.",
    //   };
    // }

    // for (const token of user.deviceTokens) {
    //   await sendPushNotification(
    //     {
    //       notification: notificationData,
    //       token,
    //     },
    //     user.toJSON()
    //   );
    // }
    // const notification = new Notification({
    //   ...notificationData,
    //   userId: userId,
    //   uid: uid,
    // });
    // await notification.save();
    await enquiry.save();
    res.json({
      message: `Enquiry ${enquiry.status} successfully`,
      enquiry,
    });
  } catch (e) {
    console.log("ee", e);
    res
      .status(500)
      .json({ message: "Failed to update Enquiry status", error: "e.message" });
  }
};

exports.deleteEnquiryById = async (req, res) => {
  console.log(req.params.id);
  try {
    const deletedEnquiry = await Enquiry.findByIdAndRemove(req.params.id);
    console.log(deletedEnquiry);
    if (deletedEnquiry) {
      res.json({ message: "Enquiry deleted successfully" });
    } else {
      res.status(404).json({ err: "Enquiry not found" });
    }
  } catch (err) {
    console.log(err);
    res.status(500).json({ err });
  }
};
