const Hospital = require("../../model/Hospital");
const mongoose = require("mongoose");

const getAllHospitals = async (req, res) => {
  try {
    console.log("xx", req.query);

    const {
      country,
      city,
      dept,
      page,
      gender,
      languages,
      pageSize,
      isDashboard,
    } = req.query;

    let filter = {};
    if (!isDashboard) {
      filter.status = { $ne: "banned" };
    }

    const queryArray = [];

    if (city) {
      queryArray.push({ "location.city": new RegExp(city, "i") });
    }

    if (country) {
      queryArray.push({ "location.country": new RegExp(country, "i") });
    }

    if (dept) {
      queryArray.push({ "department.id": new mongoose.Types.ObjectId(dept) });
    }
    if (Object.keys(filter).length > 0) {
      queryArray.push(filter);
    }
    console.log("queryArray", queryArray);
    const aggpipeline = [];
    if (gender) {
      aggpipeline.push({
        $lookup: {
          from: "doctors",
          localField: "doctor",
          foreignField: "_id",
          as: "doctors_info",
        },
      });
      aggpipeline.push({
        $match: {
          "doctors_info.gender": gender,
        },
      });
    }
    if (languages && Array.isArray(languages)) {
      aggpipeline.push({
        $lookup: {
          from: "doctors",
          localField: "doctor",
          foreignField: "_id",
          as: "doctors_info",
        },
      });
      aggpipeline.push({
        $match: {
          "doctors_info.languages": { $in: languages },
        },
      });
    }
    // const hospitals = await Hospital.find({
    //   $and: queryArray.length > 0 ? queryArray : [{}],
    // })
    //   .skip((page - 1) * pageSize)
    //   .limit(pageSize);
    const pageInt = parseInt(page);
    const hospitals = await Hospital.aggregate([
      {
        $match: {
          $and: queryArray.length > 0 ? queryArray : [{}],
        },
      },
      ...aggpipeline,
      ...(page && pageSize
        ? [{ $skip: (parseInt(page) - 1) * parseInt(pageSize) }]
        : []),
      ...(pageSize ? [{ $limit: parseInt(pageSize) }] : []),
    ]);

    // const totalCount = await Hospital.find({
    //   $and: queryArray.length > 0 ? queryArray : [{}],
    // }).count();
    const totalCountPipeline = [
      ...aggpipeline,
      {
        $count: "total",
      },
    ];
    const countResult = await Hospital.aggregate([
      {
        $match: {
          $and: queryArray.length > 0 ? queryArray : [{}],
        },
      },
      ...totalCountPipeline,
    ]);
    const totalCount = countResult.length > 0 ? countResult[0].total || 0 : 0;
    console.log("hhh", hospitals);
    console.log("totalCount", totalCount);
    res.json({ hospitals, totalCount });
  } catch (error) {
    console.error("Error fetching hospitals:", error);
    res.status(500).json(error);
  }
};

module.exports = getAllHospitals;
