const { validationResult } = require('express-validator');
const { generateResetToken } = require('../../service/JWT');
const { sendMail } = require('../../service/sendMail');
const Users = require('../../model/Users');
const jwt = require('jsonwebtoken');
const { decodeResetToken } = require('../../controllers/auth/resetPassword'); // Import the decodeResetToken function

// Controller for forgot password
exports.forgotPassword = async (req, res) => {
  const { email } = req.body;
  const errors = validationResult(req);

  if (!errors.isEmpty()) {
    return res.status(400).json({ errors: errors.array() });
  }

  try {
    const user = await Users.findOne({ email });

    if (!user) {
      return res.status(404).json({ message: "User doesn't exist" });
    }

    // Generate a reset token
    const resetToken =generateResetToken({ userId: user._id });

    user.resetToken = resetToken;
    await user.save();
    // Create a reset link
    // const resetLink = `https://inecare.com/resetpassword/${resetToken}`;
    const resetLink = encodeURI(`${process.env.CLIENT_URL}/auth/resetpassword?token=${resetToken}`);

    // Send the reset link via email
    const mailOptions = {
      from: process.env.AUTH_EMAIL,
      to: user.email,
      subject: 'Reset Your Password',
      // html: `<!DOCTYPE html>
      // <html lang="en">
      
      // <head>
      //   <meta charset="UTF-8">
      //   <meta name="viewport" content="width=device-width, initial-scale=1.0">
      //   <title>Open My App</title>
      //   <style>
      //     body {
      //       font-family: 'Arial', sans-serif;
      //       text-align: center;
      //       padding: 20px;
      //     }
      
      //     .container {
      //       max-width: 600px;
      //       margin: 0 auto;
      //     }
      
      //     .button {
      //       display: inline-block;
      //       padding: 10px 20px;
      //       background-color: #4CAF50;
      //       color: #ffffff;
      //       text-decoration: none;
      //       border-radius: 5px;
      //     }
      //   </style>
      // </head>
      
      // <body>
      //   <div class="container">
      //     <h1>Open My App</h1>
      //     <p>Click the button below to open my app:</p>
      //     <script>
      //     function openApp() {
      //       // Attempt to open the app using the custom URI scheme
      //       window.location.href = 'inecare://resetpassword/${resetToken}';
      //       // Fallback: Open the web URL if the custom scheme is not supported
      //       setTimeout(() => {
      //         window.location.href = 'https://inecare.com/resetpassword/${resetToken}';
      //       }, 100);
      //     }
      //     <script>
      //     function openApp() {
      //       // Encode the reset token
      //       var encodedToken = encodeURIComponent('${resetToken}');
      //       // Attempt to open the app using the custom URI scheme
      //       window.location.href = 'inecare://resetpassword/' + encodedToken;
      //       // Fallback: Open the web URL if the custom scheme is not supported
      //       setTimeout(() => {
      //         window.location.href = 'https://inecare.com/resetpassword/' + encodedToken;
      //       }, 100);
      //     }
      //   </script>
      //   <a class="button" href="#" onclick="openApp()">Open App</a>
      //   <p>If you don't have the app installed, you can <a href="https://inecare.com/resetpassword/${resetToken}">visit our website</a>.</p>
      //   </div>
      // </body>
      
      // </html>`,
      html: 
      // `Click the following link to reset password ${resetLink}`,
      `
      <p>Hello ${user.name || 'User'},</p>
      <p>We received a request to reset your password. Click the button below to create a new password:</p>
      <a href="${resetLink}">
        <button style="background-color: #06B1D0; color: #ffffff; padding: 10px 20px; border-radius: 5px; border: none; cursor: pointer;">Reset Password</button>
      </a>
      <p>If you didn't request a password reset, you can ignore this email. Your password will remain unchanged.</p>
      <p>If you're having trouble clicking the button, copy and paste the following link into your browser:</p>
      <p>${resetLink}</p>
      <p>Thanks,</p>

  `,
      
    };

    await sendMail(mailOptions);

    return res.status(200).json({ message: 'Password reset link sent successfully' });
    console.log(res)
  } catch (error) {
    console.error(error);
    return res.status(500).json({ status: 'FAILED', message: 'Internal Server Error' });
  }
};
