const { validationResult } = require("express-validator");
const {
  generateAccessToken,
  generateRefreshToken,
} = require("../../service/JWT");
const Users = require("../../model/Users");
const crypto = require("crypto");

module.exports = async function (req, res) {
  const { email, password, type, phone } = req.body;
  console.log(req.body);
  const errors = validationResult(req);
  if (!errors.isEmpty()) {
    return res.status(400).json({ errors: errors.array() });
  }

  try {
    const match = { status: "active" };
    if (type === "email") {
      match.email = email;
    } else {
      match.phone = phone;
    }
    const user = await Users.findOne(match);
    console.log("user is ", user);

    if (!user) {
      return res.status(404).json({ message: "User doesn't exist" });
    }

    if (await user.validPassword(password)) {
      const id = user._id;
      const accessToken = generateAccessToken({ id });
      const refreshToken = generateRefreshToken({ id });

      return res.status(201).json({
        status: "SUCCESS",
        message: "User Logged In successfully",
        accessToken,
        refreshToken,
      });
    } else {
      return res
        .status(400)
        .json({ status: "FAILED", message: "Incorrect password" });
    }
  } catch (error) {
    console.error(error);
    return res
      .status(500)
      .json({
        status: "FAILED",
        error: error.message,
        message: "Internal Server Error",
      });
  }
};
