const { validationResult } = require("express-validator");
const { generateAccessToken } = require("../../service/JWT");
const User = require("../../model/Users");
const Token = require("../../model/token");
const crypto = require("crypto");
const { sendMail } = require("../../service/sendMail");

async function sendVerificationEmail(req, res) {
  let { name, email } = req.body;

  const errors = validationResult(req);
  if (!errors.isEmpty()) {
    return res.status(400).json({ errors: errors.array() });
  }

  try {
    const user = await User.findOne({ email, status: "active" });

    if (!user) {
      return res.status(404).json({ message: "User not found" });
    }
    const existingToken = await Token.findOne({ userId: user._id });
    if (existingToken) {
      const verificationToken = existingToken.token;
      const url = encodeURI(
        `${process.env.CLIENT_URL}/auth/verify?userId=${user._id}&token=${verificationToken}`
      );
      await sendMail({
        to: email,
        subject: "Resend Verification Email",
        html: `
        <p>Hello ${name || "User"},</p>
        <p>Thank you for registering with us!</p>
        <p>Please click the following link to verify your email:</p>
        <a href="${url}" target="_blank">${url}</a>
        <p>If you didn't sign up for our service, you can ignore this email.</p>
        <p>Thank you!</p>
        `,
        // text: `Click on the following link to verify your email: ${url}`,
      });

      return res
        .status(200)
        .json({ message: "Resent verification email successfully." });
    }
    if (!existingToken) {
      const verificationToken = generateAccessToken({ userId: user._id });
      const token = new Token({
        userId: user._id,
        token: verificationToken,
      });
      await token.save();
      const url = encodeURI(
        `${process.env.CLIENT_URL}/auth/verify?userId=${user._id}&token=${verificationToken}`
      );
      await sendMail({
        to: email,
        subject: "Verify Email",
        // text: `Click on the following link to verify your email: ${url}`,
        html: `
        <p>Hello ${name || "User"},</p>
        <p>Thank you for registering with us!</p>
        <p>Please click the following link to verify your email:</p>
        <a href="${url}" target="_blank">${url}</a>
        <p>If you didn't sign up for our service, you can ignore this email.</p>
        <p>Thank you!</p>
        `,
      });
    }
    return res
      .status(200)
      .json({ message: "Verification email sent successfully." });
  } catch (error) {
    console.error(error);
    return res
      .status(500)
      .json({ error, message: "Failed to send verification email." });
  }
}

module.exports = sendVerificationEmail;
