const { validationResult } = require("express-validator");
const {
  generateAccessToken,
  generateRefreshToken,
} = require("../../service/JWT");
const User = require("../../model/Users");
const Token = require("../../model/token");
const crypto = require("crypto");
const { sendMail } = require("../../service/sendMail");

module.exports = async function (req, res) {
  let { name, phone, email, password } = req.body;

  const errors = validationResult(req);
  if (!errors.isEmpty()) {
    return res.status(400).json({ errors: errors.array() });
  }

  try {
    const user = await User.findOne({ email });

    if (user) {
      if (user.status === "active") {
        return res.status(403).json({ message: "User already exists" });
      }
    }

    const newUser = new User({ name, phone, email, password });
    newUser.setPassword(password);
    const savedUser = await newUser.save();

    const id = savedUser._id;
    // const accessToken = generateAccessToken({ id });
    // const refreshToken = generateRefreshToken({ id });

    // // Send verification email
    // const token = await new Token({
    //     userId: id,
    //     token: crypto.randomBytes(32).toString("hex"),
    // }).save();
    const verificationToken = generateAccessToken({ userId: id });

    // Save the token to the Token model
    const token = new Token({
      userId: id,
      token: verificationToken,
    });
    await token.save();
    const url = encodeURI(
      `${process.env.CLIENT_URL}/auth/verify?userId=${id}&token=${verificationToken}`
    );
    await sendMail({
      to: email,
      subject: "Verify Email",
      // text: `Click on the following link to verify your email: ${url}`,
      html: `
            <p>Hello ${name || "User"},</p>
            <p>Thank you for registering with us!</p>
            <p>Please click the following link to verify your email:</p>
            <a href="${url}" target="_blank">${url}</a>
            <p>If you didn't sign up for our service, you can ignore this email.</p>
            <p>Thank you!</p>
        `,
    });

    const accessToken = generateAccessToken({ id });
    const refreshToken = generateRefreshToken({ id });

    return res
      .status(201)
      .json({
        accessToken,
        refreshToken,
        message: "User registered successfully. Verification email sent.",
      });
  } catch (error) {
    console.error(error);
    return res.status(500).json({ error, message: "User registration failed" });
  }
};
