const mongoose = require("mongoose");
const Clinic = require("../../model/Clinic");

const createReview = async (req, res) => {
  const { userId, rating, review } = req.body;
  const clinicId = req.params.id;

  try {
    const clinic = await Clinic.findById(clinicId);
    if (!clinic) {
      return res.status(404).json({ message: "Clinic not found" });
    }

    const userObjectId = mongoose.Types.ObjectId.createFromHexString(userId);
    const existingReview = clinic.reviews.find((rev) => rev.userId.equals(userObjectId));
    console.log(existingReview)

    if (existingReview) {
      // User has already submitted a review, update it
      existingReview.rating = rating;
      existingReview.review = review;
    } else {
      // User has not submitted a review, create a new one
      const newReview = {
        rating,
        review,
        userId: userObjectId,
      };
      
      clinic.reviews.push(newReview);
    }

    await clinic.save();
    res.status(201).json({ message: "Review created/updated successfully" });
  } catch (error) {
    console.error("Error creating/update review:", error);
    res.status(500).json({ message: "Internal server error" });
  }
};

module.exports = {
  createReview,
};
