const Clinic = require("../../model/Clinic");
const mongoose = require("mongoose");

const getAllClinics = async (req, res) => {
  try {
    console.log(req.query);
    const {
      city,
      country,
      dept,
      page,
      gender,
      languages,
      pageSize,
      isDashboard,
    } = req.query;

    let filter = {};
    if (!isDashboard) {
      filter.status = { $ne: "banned" };
    }
    const queryArray = [];

    if (city) {
      queryArray.push({ "location.city": new RegExp(city, "i") });
    }

    if (country) {
      queryArray.push({ "location.country": new RegExp(country, "i") });
    }

    if (dept) {
      queryArray.push({ "department.id": new mongoose.Types.ObjectId(dept) });
    }
    if (Object.keys(filter).length > 0) {
      queryArray.push(filter);
    }
    console.log("queryArray", queryArray);
    const aggpipeline = [];
    if (gender) {
      aggpipeline.push({
        $lookup: {
          from: "doctors",
          localField: "doctor",
          foreignField: "_id",
          as: "doctors_info",
        },
      });
      aggpipeline.push({
        $match: {
          "doctors_info.gender": gender,
        },
      });
    }
    if (languages && Array.isArray(languages)) {
      aggpipeline.push({
        $lookup: {
          from: "doctors",
          localField: "doctor",
          foreignField: "_id",
          as: "doctors_info",
        },
      });
      aggpipeline.push({
        $match: {
          "doctors_info.languages": { $in: languages },
        },
      });
    }
    const clinics = await Clinic.aggregate([
      {
        $match: {
          $and: queryArray.length > 0 ? queryArray : [{}],
        },
      },
      ...aggpipeline,
      ...(page && pageSize
        ? [{ $skip: (parseInt(page) - 1) * parseInt(pageSize) }]
        : []),
      ...(pageSize ? [{ $limit: parseInt(pageSize) }] : []),
    ]);
    const totalCountPipeline = [
      ...aggpipeline,
      {
        $count: "total",
      },
    ];
    const countResult = await Clinic.aggregate([
      {
        $match: {
          $and: queryArray.length > 0 ? queryArray : [{}],
        },
      },
      ...totalCountPipeline,
    ]);
    const totalCount = countResult.length > 0 ? countResult[0].total || 0 : 0;
    console.log("hhh", clinics);
    console.log("totalCount", totalCount);
    res.json({ clinics, totalCount });

    // const clinics = await Clinic.find({
    //   $and: [
    //     { "location.city": new RegExp(city, "i") },
    //     { "location.country": new RegExp(country, "i") },
    //     ...(dept
    //       ? [{ "department.id": new mongoose.Types.ObjectId(dept) }]
    //       : []),
    //   ],
    // })
    //   .skip((page - 1) * pageSize)
    //   .limit(pageSize);

    // const totalCount = await Clinic.find({
    //   $and: [
    //     { "location.city": new RegExp(city, "i") },
    //     { "location.country": new RegExp(country, "i") },
    //     ...(dept
    //       ? [{ "department.id": new mongoose.Types.ObjectId(dept) }]
    //       : []),
    //   ],
    // }).count();
    // console.log("totalCount", totalCount);
    // res.status(200).json({ clinics, totalCount });
  } catch (err) {
    console.log(err);
    res.status(500).json({ error: err.message });
  }
};

module.exports = getAllClinics;
