const mongoose = require("mongoose");

const locationSchema = new mongoose.Schema({
  latitude: Number,
  longitude: Number,
  address: String,
  city: String,
  country: String,
});
const reviewSchema = new mongoose.Schema({
  rating: {
    type: Number,
    required: true,
  },
  review: {
    type: String,
    required: true,
  },
  userId: {
    type: mongoose.Schema.Types.ObjectId,
    ref: "User",
  },
});
const clinicSchema = new mongoose.Schema(
  {
    name: String,
    location: locationSchema,
    bedCapacity: Number,
    contactInfo: String,
    department: [
      {
        id: { type: mongoose.Schema.Types.ObjectId, ref: "Department" },
        treatment: [{ type: mongoose.Schema.Types.ObjectId, ref: "Treatment" }],
      },
    ],
    doctor: [
      {
        type: mongoose.Schema.Types.ObjectId,
        ref: "Doctor",
      },
    ],
    enquiry: [
      {
        type: String,
      },
    ],
    featured: {
      type: Boolean,
      default: false,
    },
    working_hours: String,
    description: String,
    image: String,
    status: {
      type: String,
      enum: ["active", "banned"],
      default: "active",
    },
    lab: {
      type: Boolean,
      default: "false",
    },
    favorites: [
      {
        type: mongoose.Schema.Types.ObjectId,
        ref: "User",
      },
    ],

    reviews: [reviewSchema],
  },
  { timestamps: true }
);

const Clinic = mongoose.model("Clinic", clinicSchema);

module.exports = Clinic;
