const mongoose = require("mongoose");

const educationSchema = new mongoose.Schema({
  degree: {
    type: String,
    required: true,
  },
});

const locationSchema = new mongoose.Schema({
  latitude: Number,
  longitude: Number,
  address: String,
  city: String,
  country: String,
});
const reviewSchema = new mongoose.Schema({
  rating: {
    type: Number,
    required: true,
  },
  review: {
    type: String,
    required: true,
  },
  userId: {
    type: mongoose.Schema.Types.ObjectId,
    ref: "User",
  },
});
const DoctorSchema = new mongoose.Schema({
  name: String,
  contactInfo: String,
  description: String,
  workexperience: String,
  education: [educationSchema],
  achievements: [
    {
      title: {
        type: String,
        required: true,
      },
    },
  ],
  department: [
    {
      type: mongoose.Schema.Types.ObjectId,
      ref: "Department",
    },
  ],
  enquiry: [
    {
      type: String,
    },
  ],
  // department: [String],
  qualification: String,
  clinicalinterest: String,
  location: locationSchema,

  image: String,

  status: {
    type: String,
    enum: ["active", "banned"],
    default: "active",
  },
  isFreelancer: {
    type: Boolean,
    default: false,
  },
  certificationNumber: {
    type: String,
  },

  certificationDocument: String,

  startTime: {
    type: String,
  },
  endTime: {
    type: String,
  },
  gender: {
    type: String,
    enum: ['male', 'female', 'other'],
    required: true,
  },
  languages: [{ type: String }],
  workingDays: [{ type: String }],
  favorites: [
    {
      type: mongoose.Schema.Types.ObjectId,
      ref: "User",
    },
  ],
  reviews: [reviewSchema],
});

const Doctor = mongoose.model("Doctor", DoctorSchema);

module.exports = Doctor;
