const mongoose = require("mongoose");
const locationSchema = new mongoose.Schema({
  latitude: Number,
  longitude: Number,
  address: String,
  city: String,
  country: String,
});

const reviewSchema = new mongoose.Schema({
  rating: {
    type: Number,
    required: true,
  },
  review: {
    type: String,
    required: true,
  },
  userId: {
    type: mongoose.Schema.Types.ObjectId,
    ref: "User",
  },
});
const hospitalSchema = new mongoose.Schema(
  {
    name: String,
    location: locationSchema,
    contactInfo: String,
    bedCapacity: Number,

    description: String,
    doctor: [
      {
        type: mongoose.Schema.Types.ObjectId,
        ref: "Doctor",
      },
    ],
    department: [
      {
        id: { type: mongoose.Schema.Types.ObjectId, ref: "Department" },
        treatment: [{ type: mongoose.Schema.Types.ObjectId, ref: "Treatment" }],
      },
    ],
    enquiry: [
      {
        type: String,
      },
    ],
    image: String,
    lab: {
      type: Boolean,
      default: "false",
    },
    featured: { type: Boolean, default: false },
    status: {
      type: String,
      enum: ["active", "banned"],
      default: "active",
    },
    favorites: [
      {
        type: mongoose.Schema.Types.ObjectId,
        ref: "User",
      },
    ],
    reviews: [reviewSchema],
  },
  { timestamps: true }
);

const Hospital = mongoose.model("Hospital", hospitalSchema);

module.exports = Hospital;
