const mongoose = require("mongoose");
const crypto = require("crypto");

const UserSchema = new mongoose.Schema(
  {
    name: String,
    phone: String,
    email: String,
    country: String,
    city: String,
    gender: {
      type: String,
      enum: ["male", "female", "other"],
    },
    dateofBirth: Date,
    avatar: { type: String },
    verifications: {
      user: Boolean,
      email: Boolean,
      phone: Boolean,
    },
    hash: String,
    salt: String,
    role: { type: String, default: "user", enum: ["admin", "user"] },
    resetToken: { type: String },
    refreshTokens: { type: [String], default: [] },
    deviceTokens: { type: [String], default: [] },
    status: {
      type: String,
      enum: ["active", "banned"],
      default: "active",
    },
    newsletter: { type: String },
  },
  { timestamps: true }
);
UserSchema.methods.setPassword = function (password) {
  // Creating a unique salt for a particular user
  this.salt = crypto.randomBytes(16).toString("hex");
  // Hashing user's salt and password with sha512 algorithm,
  const hash = crypto.createHmac("sha512", this.salt);
  hash.update(password);
  this.hash = hash.digest("hex");
};

UserSchema.methods.validPassword = function (password) {
  if (!this.hash) {
    throw new Error("Password not set choose another login method");
  }
  const hash = crypto.createHmac("sha512", this.salt);
  hash.update(password);
  const passwordHash = hash.digest("hex");
  return passwordHash === this.hash;
};

module.exports = mongoose.model("User", UserSchema);
