const Department = require("../model/Department");
const express = require("express");
const router = express.Router();
const multer = require("multer");
const listdepartmentController = require("../controllers/Department/listdepartment");
const createdepartmentController = require("../controllers/Department/createdepartment");
const updatedepartmentController = require("../controllers/Department/updatedepartment");
const deletedepartmentController = require("../controllers/Department/deletedepartment");
const toggleStatus = require("../controllers/Department/toggleStatus");
const doctorcountPerdept=require("../controllers/Department/getdoctorcountperdept")
const fs = require("fs");

const storage = multer.diskStorage({
  destination: function (req, file, cb) {
    const pathName = "public/uploads/departments";
    if (!fs.existsSync(pathName)) {
      fs.mkdirSync(pathName, { recursive: true });
    }
    cb(null, pathName);
  },
  filename: function (req, file, cb) {
    console.log(Date.now() + "-" + file.originalname);
    cb(null, `${Date.now().toString()}-${file.originalname}`);
  },
});

const upload = multer({ storage: storage });

// List all departments
router.get("/", listdepartmentController.listDepartments);
router.get("/dept",listdepartmentController.getDepts)

// Get a single department by ID
router.get("/doctor-counts",doctorcountPerdept.getDoctorCountPerDepartment)
router.get("/:departmentId", listdepartmentController.getDepartmentById);

// Add a department with image upload
router.post(
  "/add",
  upload.single("image"),
  createdepartmentController.addDepartment
);

// Update a department with image upload
router.put(
  "/update/:departmentId",
  upload.single("image"),
  updatedepartmentController.updateDepartment
);

// Delete a department
router.delete(
  "/delete/:departmentId",
  deletedepartmentController.deleteDepartment
);

router.patch("/:id", toggleStatus);

module.exports = router;
