const express = require("express");
const router = express.Router();
const multer = require("multer");
const createBanner = require("../controllers/Banner/create");
const getAllBanners = require("../controllers/Banner/get");
const getBannerById = require("../controllers/Banner/getId");
const updateBannerById = require("../controllers/Banner/update");
const deleteBannerById = require("../controllers/Banner/delete");

const fs = require("fs");
const storage = multer.diskStorage({
  destination: function (req, file, cb) {
    const pathName = "public/uploads/banners";
    if (!fs.existsSync(pathName)) {
      fs.mkdirSync(pathName, { recursive: true });
    }
    cb(null, pathName);
  },
  filename: function (req, file, cb) {
    console.log(Date.now() + "-" + file.originalname);
    cb(null, `${Date.now().toString()}-${file.originalname}`);
  },
});
const upload = multer({ storage: storage });

module.exports = { upload };

router.get("/", getAllBanners);
router.post("/add", upload.single("banner"), createBanner);
router.get("/:id", getBannerById);
router.put("/:id", upload.single("banner"), updateBannerById);
router.delete("/:id", deleteBannerById);

module.exports = router;
