const multer = require("multer");
const express = require("express");
const router = express.Router();
const createClinicController = require("../controllers/clinic/create");
const updateClinicController = require("../controllers/clinic/update");
const getClinicController = require("../controllers/clinic/get");
const getIdController = require("../controllers/clinic/getid");
const deleteClinicController = require("../controllers/clinic/delete");
const toggleStatus = require("../controllers/clinic/toggleStatus");
const favorite = require("../controllers/clinic/favorite");
const unfavorite = require("../controllers/clinic/unfavorite");
const review = require("../controllers/clinic/createReview");

const fs = require("fs");
const storage = multer.diskStorage({
  destination: function (req, file, cb) {
    const pathName = "public/uploads/clinics";
    if (!fs.existsSync(pathName)) {
      fs.mkdirSync(pathName, { recursive: true });
    }
    cb(null, pathName);
  },
  filename: function (req, file, cb) {
    console.log(Date.now() + "-" + file.originalname);
    cb(null, `${Date.now().toString()}-${file.originalname}`);
  },
});
const upload = multer({ storage: storage });

module.exports = { upload };

router.post("/", upload.single("image"), createClinicController);
router.get("/", getClinicController);
router.get("/:id", getIdController);
router.put("/:id", upload.single("image"), updateClinicController);
router.patch("/:id", toggleStatus);
router.delete("/:id", deleteClinicController);

router.post("/favorite/:id", favorite.favoriteClinic);
router.post("/unfavorite/:id", unfavorite.unfavoriteClinic);

router.post("/review/:id", review.createReview);

module.exports = router;
