const express = require("express");
const router = express.Router();
const multer=require('multer')
const createDoctor = require("../controllers/Doctor/create");
const getAllDoctors = require("../controllers/Doctor/get");
const getDoctorById = require("../controllers/Doctor/getid");
const updateDoctorById = require("../controllers/Doctor/update");
const deleteDoctorById = require("../controllers/Doctor/delete");
const toggleStatus=require("../controllers/Doctor/toggleStatus");
const favorite = require("../controllers/Doctor/favorite");
const unfavorite = require("../controllers/Doctor/unfavorite");
const review=require("../controllers/Doctor/createReview")

const fs=require('fs')
const storage = multer.diskStorage({
    destination: function (req, file, cb) {
      const pathName="public/uploads/doctors";
      if (!fs.existsSync(pathName)) {
        fs.mkdirSync(pathName, { recursive: true });
      }
      cb(null, pathName);
    },
    filename: function (req, file, cb) {
      console.log(Date.now() + "-" + file.originalname);
      cb(null, `${Date.now().toString()}-${file.originalname}`);
    },
  });
  const upload = multer({ storage: storage }).fields([
    { name: 'image', maxCount: 1 },
    { name: 'certificationDocument', maxCount: 1 },
  ]);

router.get("/",getAllDoctors);
router.post("/add",upload, createDoctor);
router.patch("/:id", toggleStatus);
router.get("/:id", getDoctorById);
router.put("/:id",upload,updateDoctorById);
router.delete("/:id", deleteDoctorById);

router.post("/favorite/:id", favorite.favoriteDoctor);
router.post("/unfavorite/:id", unfavorite.unfavoriteDoctor);

router.post("/review/:id",review.createReview)

module.exports = router;
