const express = require("express");
const router = express.Router();
const multer = require("multer");
const createHealthCare = require("../controllers/HealthCare/create");
const getAllHealthCare = require("../controllers/HealthCare/get");
const getHealthCareById = require("../controllers/HealthCare/getid");
const updateHealthCareById = require("../controllers/HealthCare/update");
const deleteHealthCareById = require("../controllers/HealthCare/delete");
const toggleStatus = require("../controllers/HealthCare/toggleStatus");
const favorite = require("../controllers/HealthCare/favorite");
const unfavorite = require("../controllers/HealthCare/unfavorite");
const review=require("../controllers/HealthCare/createReview")

const fs = require("fs");
const storage = multer.diskStorage({
  destination: function (req, file, cb) {
    const pathName = "public/uploads/healthcare";
    if (!fs.existsSync(pathName)) {
      fs.mkdirSync(pathName, { recursive: true });
    }
    cb(null, pathName);
  },
  filename: function (req, file, cb) {
    console.log(Date.now() + "-" + file.originalname);
    cb(null, `${Date.now().toString()}-${file.originalname}`);
  },
});
const upload = multer({ storage: storage });

router.post("/add", upload.single("image"), createHealthCare);
router.get("/", getAllHealthCare);
router.get("/:id", getHealthCareById);
router.patch("/:id", toggleStatus);
router.put("/update/:id", upload.single("image"), updateHealthCareById);
router.delete("/delete/:id", deleteHealthCareById);

router.post("/favorite/:id", favorite.favoriteHealthCare);
router.post("/unfavorite/:id", unfavorite.unfavoriteHealthCare);

router.post("/review/:id",review.createReview)
module.exports = router;
