const express = require("express");
const router = express.Router();
const multer = require("multer");
const createHospital = require("../controllers/Hospital/create");
const getAllHospitals = require("../controllers/Hospital/get");
const getHospitalById = require("../controllers/Hospital/getid");
const updateHospitalById = require("../controllers/Hospital/update");
const deleteHospitalById = require("../controllers/Hospital/delete");
const toggleStatus = require("../controllers/Hospital/toggleStatus");
const favorite = require("../controllers/Hospital/favorite");
const unfavorite = require("../controllers/Hospital/unfavorite");
const review = require("../controllers/Hospital/createReview");
const getHospitalsByLocation = require("../controllers/Hospital/hospitalbylocation");
// const { authenticateToken } = require("../service/JWT");

const fs = require("fs");
const storage = multer.diskStorage({
  destination: function (req, file, cb) {
    const pathName = "public/uploads/hospitals";
    if (!fs.existsSync(pathName)) {
      fs.mkdirSync(pathName, { recursive: true });
    }
    cb(null, pathName);
  },
  filename: function (req, file, cb) {
    console.log(Date.now() + "-" + file.originalname);
    cb(null, `${Date.now().toString()}-${file.originalname}`);
  },
});
const upload = multer({ storage: storage });

router.post("/add", upload.single("image"), createHospital);
router.get("/", getAllHospitals);
router.get("/:id", getHospitalById);
router.patch("/:id", toggleStatus);
router.put("/update/:id", upload.single("image"), updateHospitalById);
router.delete("/delete/:id", deleteHospitalById);

router.post("/favorite/:id", favorite.favoriteHospital);
router.post("/unfavorite/:id", unfavorite.unfavoriteHospital);

router.post("/review/:id", review.createReview);
router.get("/bylocation", getHospitalsByLocation);

module.exports = router;
