var express = require("express");
const getBySession = require("../controllers/users/getBySession");
const checkUserRole = require("../middlewears/checkUserRole");
const getAllUsers = require("../controllers/users/getAllUsers");
const deleteUser = require("../controllers/users/deleteUser");
const toggleStatus = require("../controllers/users/toggleStatus");
const updateProfile = require("../controllers/users/updateProfile");
const multer = require("multer");
const fs = require("fs");
const changePassword = require("../controllers/users/changePassword");
const deleteAccount = require("../controllers/users/deleteAccount");
const deviceToken=require("../controllers/users/deviceToken")
const userDetails=require("../controllers/users/userDetails")
const logout = require("../controllers/users/logout");
const subscription=require("../controllers/users/newsletter")
const contact=require("../controllers/users/contact")


var router = express.Router();

const storage = multer.diskStorage({
  destination: function (req, file, cb) {
    const folderName = file.fieldname.replace(/\[|\]/g, "/").replace(/\/$/, "");
    const pathName = `public/uploads/${folderName}`;
    if (!fs.existsSync(pathName)) {
      fs.mkdirSync(pathName, { recursive: true });
    }
    cb(null, pathName);
  },
  filename: function (req, file, cb) {
    const uniqueSuffix = `${Date.now()}-${Math.round(Math.random() * 1e9)}`;
    cb(null, `${uniqueSuffix}${file.originalname}`);
  },
});

const upload = multer({ storage });

const isAdmin = checkUserRole("admin");

router.put("/profile", upload.single("avatar"), updateProfile);
router.post("/password/change", changePassword);
router.delete("/account", deleteAccount);
router.get("/user/:id",userDetails)
router.post("/logout", logout);
router.get("/user", getBySession);
router.get("/", isAdmin, getAllUsers);
router.delete("/:id", isAdmin, deleteUser);
router.patch("/status/:id", isAdmin, toggleStatus);
router.post("/deviceToken",deviceToken)
router.post("/subscription",subscription)
router.post("/contact",contact)


module.exports = router;
