const jwt = require("jsonwebtoken");
const User = require("../model/Users");

function generateAccessToken(user) {
  return jwt.sign(user, process.env.JWT_SECRET, { expiresIn: "30d" });
}

function generateResetToken(user) {
  return jwt.sign(user, process.env.JWT_SECRET, { expiresIn: 600 });
}

function generateRefreshToken(user) {
  return jwt.sign(user, process.env.JWT_SECRET, { expiresIn: "30d" });
}
function verifyResetToken(token) {
  return new Promise((resolve, reject) => {
    jwt.verify(token, process.env.JWT_SECRET, (err, data) => {
      if (err) {
        reject(err);
      }
      resolve(data);
    });
  });
}
function authenticateToken(req, res, next) {
  const authHeader = req.headers["authorization"];
  const token = authHeader && authHeader.split(" ")[1];

  if (token == null) return res.sendStatus(401);

  jwt.verify(token, process.env.JWT_SECRET, async(err, data) => {
    if (err) return res.status(401).json({ error: "Access token expired" });
    try {
      const user = await User.findById(data.id, {
        hash: 0,
        salt: 0,
        refreshTokens: 0,
      });
      if (user?.status === "active") {
        req.user = user.toJSON();
        req.user.id = user._id.toString();
        next();
      } else {
        return res.status(403).json({ message: "Permission denied" });
      }
    } catch (err) {
      return res
        .status(403)
        .json({ error: err.message, message: "Permission denied" });
    }
  });
}

module.exports = {
  generateAccessToken,
  generateRefreshToken,
  authenticateToken,
  verifyResetToken,
  generateResetToken,
};
